insert_founder and convert. Please look up their
documentation with help(Converter$insert_founder) and help(Converter$convert).
Before starting conversion, all founder alleles and founder genotypes have to be added via
the method insert_founder. Conversion is then done by the method convert.The constructor has two parameters, positions and use_names
(optional, defaults to FALSE).
Parameter positions must be a list of vectors with the genetic positions.
If these vectors are named, and if use_names is TRUE,
the result of a conversion via convert will also be named.
Please see the vignette (vignette('Introduction', package = 'Meiosis')) for an example.